package com.ruoyi.bid.service;

import java.util.List;
import com.ruoyi.bid.domain.BidInfo;

/**
 * 招标信息Service接口
 * 
 * @author ruoyi
 * @date 2025-12-09
 */
public interface IBidInfoService 
{
    /**
     * 查询招标信息
     * 
     * @param id 招标信息主键
     * @return 招标信息
     */
    public BidInfo selectBidInfoById(Long id);

    /**
     * 查询招标信息列表
     * 
     * @param bidInfo 招标信息
     * @return 招标信息集合
     */
    public List<BidInfo> selectBidInfoList(BidInfo bidInfo);

    /**
     * 新增招标信息
     * 
     * @param bidInfo 招标信息
     * @return 结果
     */
    public int insertBidInfo(BidInfo bidInfo);

    /**
     * 修改招标信息
     * 
     * @param bidInfo 招标信息
     * @return 结果
     */
    public int updateBidInfo(BidInfo bidInfo);

    /**
     * 批量删除招标信息
     * 
     * @param ids 需要删除的招标信息主键集合
     * @return 结果
     */
    public int deleteBidInfoByIds(Long[] ids);

    /**
     * 删除招标信息信息
     * 
     * @param id 招标信息主键
     * @return 结果
     */
    public int deleteBidInfoById(Long id);
}
